@@ -1,16 +1,13 @@
-#!/usr/bin/python3
-"""
-Compile and run the primes.mixal sample program using mixvm and mixguile.
-"""
+"""Compile and run the primes.mixal sample program using mixvm and mixguile."""
+
+from __future__ import annotations
 
 import os
 import pathlib
-import subprocess
+import subprocess  # noqa: S404
 import sys
 import tempfile
 
-from typing import Dict
-
 
 MIXASM = os.environ.get("TEST_MIXASM_PROG", "mixasm")
 MIXVM = os.environ.get("TEST_MIXVM_PROG", "mixvm")
@@ -24,7 +21,7 @@ ENC = "us-ascii"
 
 
 def prepare_home_dir(home_dir: pathlib.Path) -> None:
-    """ Create any necessary files in the temporary home directory. """
+    """Create any necessary files in the temporary home directory."""
     home_dir.mkdir(mode=0o755)
 
     if MIXLOCAL:
@@ -32,13 +29,14 @@ def prepare_home_dir(home_dir: pathlib.Path) -> None:
         mdk_dir = home_dir / ".mdk"
         mdk_dir.mkdir(mode=0o755)
         for path in sorted(guile_dir.glob("*.scm")):
-            subprocess.check_call(
-                ["cp", "--", path, mdk_dir], shell=False,
+            subprocess.check_call(  # noqa: S603
+                ["cp", "--", path, mdk_dir],  # noqa: S607
+                shell=False,
             )
 
 
 def examine_output(fname: pathlib.Path) -> None:
-    """ Examine the primes output file. """
+    """Examine the primes output file."""
     print(f"Examining {fname}")
     with fname.open(mode="r", encoding=ENC) as printer_file:
         line = printer_file.readline()
@@ -50,12 +48,12 @@ def examine_output(fname: pathlib.Path) -> None:
             "0239": False,
             "0048": False,
         }
-        print(f'Looking for {" ".join(sorted(found.keys()))}')
+        print(f"Looking for {' '.join(sorted(found.keys()))}")
         for line in printer_file.readlines():
             words = set(line.split())
-            for num in found:
+            for num, value in found.items():
                 if num in words:
-                    assert not found[num]
+                    assert not value
                     found[num] = True
 
         print(f"Result: {found}")
@@ -71,18 +69,18 @@ def run_program(
     program: str,
     program_dir: pathlib.Path,
     commands: str,
-    mix_env: Dict[str, str],
+    mix_env: dict[str, str],
 ) -> None:
-    """ Create a subdir and input and output files, run a program. """
+    """Create a subdir and input and output files, run a program."""
     program_dir.mkdir(mode=0o755)
     infile = program_dir / "in.txt"
     infile.write_text(commands, encoding=ENC)
     print(f"Created {infile}")
-    subprocess.check_call(["cat", "--", infile])
+    subprocess.check_call(["cat", "--", infile])  # noqa: S603,S607
 
     outfile = program_dir / "out.txt"
     print(f"Invoking {program} in {infile} out {outfile}")
-    subprocess.check_call(
+    subprocess.check_call(  # noqa: S603
         [program],
         shell=False,
         env=mix_env,
@@ -90,7 +88,7 @@ def run_program(
         stdout=outfile.open(mode="w"),
     )
     print(f"Got {program} output:")
-    subprocess.check_call(["cat", "--", outfile])
+    subprocess.check_call(["cat", "--", outfile])  # noqa: S603,S607
 
     assert sorted(path.name for path in program_dir.glob("*")) == [
         "in.txt",
@@ -103,8 +101,8 @@ def run_program(
 
 
 def test_primes() -> None:
-    """ Primes sample program test: compile, run, check. """
-    print("")
+    """Primes sample program test: compile, run, check."""
+    print()
     if not SRCFILE.is_file():
         sys.exit(f'Not a file: "{SRCFILE}"; set TEST_SRCDIR?')
 
@@ -119,7 +117,7 @@ def test_primes() -> None:
         program_base = tmpdir / "primes"
         program_full = program_base.with_suffix(".mix")
         print(f"Running {MIXASM} on {SRCFILE} to create {program_full}")
-        subprocess.check_call([MIXASM, "-o", program_base, "--", SRCFILE])
+        subprocess.check_call([MIXASM, "-o", program_base, "--", SRCFILE])  # noqa: S603
         print(f"Checking for {program_full}")
         assert sorted(path.name for path in tmpdir.glob("*")) == ["primes.mix"]
         assert program_full.is_file()
